@@ -1,19 +1,18 @@
 package AnyEvent::Impl::Event;
 
+no warnings;
+
 use Event ();
 
 sub io {
    my ($class, %arg) = @_;
    $arg{fd} = delete $arg{fh};
-   bless \(my $x = Event->io (
-      %arg,
-      cb => $arg{cb},
-   )), $class
+   bless \(my $x = Event->io (%arg)), $class
 }
 
 sub timer {
    my ($class, %arg) = @_;
-   my $cb = $arg{cb};
+   my $cb = delete $arg{cb};
    bless \(my $w = Event->timer (
       %arg,
       cb => sub {
@@ -38,7 +37,11 @@ sub broadcast {
 }
 
 sub wait {
-   Event::one_event() while !${$_[0]};
+   Event::one_event while !${$_[0]};
+}
+
+sub one_event {
+   Event::one_event;
 }
 
 1
