@@ -1,5 +1,7 @@
 package AnyEvent::Impl::Glib;
 
+no warnings;
+
 use Glib ();
 
 my $maincontext = Glib::MainContext->default;
@@ -59,5 +61,9 @@ sub wait {
    $maincontext->iteration (1) while !${$_[0]};
 }
 
+sub one_event {
+   $maincontext->iteration (1);
+}
+
 1
 
